# Changelog

## 0.1.0-alpha.1 (2024-09-10)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/li2109/vvallet-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** Config update for li2109/dev ([9fafa25](https://github.com/li2109/vvallet-python/commit/9fafa25b089e53e6107aa404dd9df3dae685de65))
* **api:** OpenAPI spec update via Stainless API ([af4a0b3](https://github.com/li2109/vvallet-python/commit/af4a0b3e9a30412322d43586c8d4f989faa68c01))


### Chores

* add docstrings to raw response properties ([f3d8993](https://github.com/li2109/vvallet-python/commit/f3d89935a30731c51a9fa01e26e173ff27121103))
* go live ([#1](https://github.com/li2109/vvallet-python/issues/1)) ([500ade6](https://github.com/li2109/vvallet-python/commit/500ade6a27248f323b5b108a677cc97c3502b5a9))
* go live ([#3](https://github.com/li2109/vvallet-python/issues/3)) ([a6360f5](https://github.com/li2109/vvallet-python/commit/a6360f52d370cebd752c6d491a24a9e62c5469e2))


### Documentation

* **readme:** add section on determining installed version ([d313e9b](https://github.com/li2109/vvallet-python/commit/d313e9b0118e83ae8b218207020e4ccb200b2ecb))
